@@ -515,6 +515,27 @@ Magic cookie.
 
 }
 
+func TestFastImportHeaderDetection(t *testing.T) {
+	type headerTestEntry struct {
+		header   string
+		expected bool
+	}
+	tests := []headerTestEntry{
+		// Test lines were derived by mining all the .fi files
+		// in the test suite, plus a deliberate non-match.
+		{"blob", true},
+		{"commit refs/heads/master", true},
+		{"feature commit-properties", true},
+		{"#reposurgeon sourcetype git", true},
+		{"#reposurgeon sourcetype svn", true},
+		{"reset refs/tags/LABEL_2002_11_05_0120", true},
+		{"random cruft", false},
+	}
+	for _, item := range tests {
+		assertBool(t, item.expected, matchesFastImportHeader([]byte(item.header)))
+	}
+}
+
 func TestDateFormats(t *testing.T) {
 	toGitdump := func(from string) string {
 		d, err := newDate(from)
@@ -1262,12 +1283,6 @@ func TestBranchbase(t *testing.T) {
 }
 
 func TestCapture(t *testing.T) {
-	data, err0 := captureFromProcess("echo stdout; echo 1>&2 stderr", control.baton)
-	if err0 != nil {
-		t.Fatalf("error while spawning process: %v", err0)
-	}
-	assertEqual(t, data, "stdout\nstderr\n")
-
 	r, cmd, err1 := readFromProcess("echo arglebargle")
 	if err1 != nil {
 		t.Fatalf("error while spawning process: %v", err1)
@@ -2023,8 +2038,7 @@ func TestFilterRegex(t *testing.T) {
 	// committer, and comment, . Replacement tested against repeat
 	// flags 0,1,2,g
 
-	rawdump := `
-blob
+	rawdump := `blob
 mark :1
 data 14
 BLB o123-o123
