@@ -6,8 +6,10 @@ stem=simpletag
 
 # No user-serviceable parts below this line
 
-command -v svn >/dev/null 2>&1 || { echo "    Skipped, svn missing."; exit 0; }
-command -v git >/dev/null 2>&1 || { echo "    Skipped, git missing."; exit 0; }
+# shellcheck disable=SC1091
+. ./common-setup.sh
+
+need svn git
 
 trap 'rm -rf /tmp/test-repo$$-svn /tmp/test-repo$$-git /tmp/out$$' EXIT HUP INT QUIT TERM
 
@@ -15,12 +17,6 @@ trap 'rm -rf /tmp/test-repo$$-svn /tmp/test-repo$$-git /tmp/out$$' EXIT HUP INT
 reposurgeon "read <${stem}.svn" "prefer git" "rebuild /tmp/test-repo$$-git" >/tmp/out$$ 2>&1
 ${REPOTOOL:-repotool} compare-tags /tmp/test-repo$$-svn /tmp/test-repo$$-git | sed -e "s/$$/\$\$/"g >/tmp/out$$ 2>&1
 
-case $1 in
-    --regress)
-        diff --text -u repotool-compare-tags-svn-git.chk /tmp/out$$ || ( echo "$0: FAILED"; exit 1 ); ;;
-    --rebuild)
-	cat /tmp/out$$ >repotool-compare-tags-svn-git.chk;;
-    --view)
-	cat /tmp/out$$;;
-esac
+toolmeta "$1" /tmp/out$$
 	      
+# end
